@@ -13,7 +13,7 @@ router = APIRouter()
 )
 async def home():
     return {
-        'title': "Welcome to REST ADMIN"
+        'title': "Welcome to FastAPI ADMIN"
     }
 
 
@@ -27,12 +27,20 @@ async def site(
     if app.permission and not user.is_superuser:
         site_ = deepcopy(site_)
         await user.fetch_related('roles')
-        for menu in site_.menus:
+        filter_menus = filter(lambda x: (x.url and 'rest' in x.url) or x.children, site_.menus)
+        hide_menus = []
+        for menu in filter_menus:
             has_permission = False
-            if not has_permission:
-                for role in user.roles:
-                    if await role.permissions.filter(model=menu.name):
+            for role in user.roles:
+                if not has_permission:
+                    model = menu.url.split('/')[-1]
+                    permission = await role.permissions.filter(model=model)
+                    if permission:
                         has_permission = True
             if not has_permission:
+                hide_menus.append(menu.url)
+        for menu in app.site.menus:
+            if menu.url in hide_menus:
                 site_.menus.remove(menu)
+
     return site_.dict(by_alias=True, exclude_unset=True)
